@@ -117,8 +117,10 @@ async def find_photometer_by_name(session: Session, name: str) -> Optional[Tess]
             NameMapping.valid_state == ValidState.CURRENT,
             Tess.valid_state == ValidState.CURRENT,
         )
+        .order_by(Tess.valid_since.desc())
     )
-    return (await session.scalars(query)).one_or_none()
+    result = (await session.scalars(query)).all()  # Thre may be several Tess with CURRENT state
+    return result[0] if result else None  # Choose the most recent
 
 
 async def lookup_mac(session: Session, mac_address: str) -> Optional[NameMapping]:
@@ -225,7 +227,7 @@ async def renaming_photometer(
 
 
 async def replacing_photometer(
-    session: Session, old_mapping: NameMapping, candidate: PhotometerInfo
+    session: Session, old_mapping: NameMapping, candidate: PhotometerInfo, source: ReadingSource
 ) -> None:
     old_mapping.valid_until = candidate.tstamp
     old_mapping.valid_state = ValidState.EXPIRED
@@ -238,38 +240,56 @@ async def replacing_photometer(
         valid_state=ValidState.CURRENT,
     )
     session.add(mapping)
-    # Copy the observer and location from the broken photometer
-    query = select(Tess.location_id, Tess.observer_id).where(
-        Tess.mac_address == old_mapping.mac_address, Tess.valid_state == ValidState.CURRENT
+
+    # maybe the candidate was already registered in the past
+    # so we must avoid creating a duplicate
+    query = (
+        select(Tess)
+        .where(Tess.mac_address == candidate.mac_address, Tess.valid_state == ValidState.CURRENT)
+        .order_by(Tess.valid_since.desc())
     )
-    location_id, observer_id = (await session.execute(query)).one()
-    photometer = Tess(
-        mac_address=candidate.mac_address,
-        valid_since=candidate.tstamp,
-        valid_until=INFINITE_T,
-        valid_state=ValidState.CURRENT,
-        model=candidate.model,
-        firmware=candidate.firmware,
-        authorised=candidate.authorised,
-        registered=candidate.registered,
-        # From 1 to 4
-        nchannels=4 if candidate.model == PhotometerModel.TESS4C else 1,
-        zp1=candidate.zp1,
-        filter1=candidate.filter1,
-        offset1=candidate.offset1,
-        zp2=candidate.zp2,
-        filter2=candidate.filter2,
-        offset2=candidate.offset2,
-        zp3=candidate.zp3,
-        filter3=candidate.filter3,
-        offset3=candidate.offset3,
-        zp4=candidate.zp4,
-        filter4=candidate.filter4,
-        offset4=candidate.offset4,
-        location_id=location_id,
-        observer_id=observer_id,
-    )
-    session.add(photometer)
+    another_tess = (await session.scalars(query)).all()
+    if another_tess:
+        another_tess = another_tess[0]
+        log.warning("Replacing back %s", dict(candidate))
+        updated = maybe_update_managed_attributes(session, candidate, another_tess)
+        if updated:
+            # self.nZPChange += 1
+            pub.sendMessage(RegisterEvent.ZP_CHANGE, source=source)
+
+    else:
+        # Copy the observer and location from the broken photometer
+        query = select(Tess.location_id, Tess.observer_id).where(
+            Tess.mac_address == old_mapping.mac_address, Tess.valid_state == ValidState.CURRENT
+        )
+        location_id, observer_id = (await session.execute(query)).one()
+        photometer = Tess(
+            mac_address=candidate.mac_address,
+            valid_since=candidate.tstamp,
+            valid_until=INFINITE_T,
+            valid_state=ValidState.CURRENT,
+            model=candidate.model,
+            firmware=candidate.firmware,
+            authorised=candidate.authorised,
+            registered=candidate.registered,
+            # From 1 to 4
+            nchannels=4 if candidate.model == PhotometerModel.TESS4C else 1,
+            zp1=candidate.zp1,
+            filter1=candidate.filter1,
+            offset1=candidate.offset1,
+            zp2=candidate.zp2,
+            filter2=candidate.filter2,
+            offset2=candidate.offset2,
+            zp3=candidate.zp3,
+            filter3=candidate.filter3,
+            offset3=candidate.offset3,
+            zp4=candidate.zp4,
+            filter4=candidate.filter4,
+            offset4=candidate.offset4,
+            location_id=location_id,
+            observer_id=observer_id,
+        )
+        session.add(photometer)
 
 
 def is_tess4c_changed(photometer: Tess, candidate: PhotometerInfo) -> bool:
@@ -351,7 +371,6 @@ def update_managed_attributes(
     session: Session,
     photometer: Tess,
     candidate: PhotometerInfo,
-    source: ReadingSource,
 ) -> None:
     photometer.valid_until = candidate.tstamp
     photometer.valid_state = ValidState.EXPIRED
@@ -383,22 +402,15 @@ def update_managed_attributes(
         offset4=candidate.offset4,
     )
     session.add(new_photometer)
-    # self.nZPChange += 1
-    pub.sendMessage(RegisterEvent.ZP_CHANGE, source=source)
 
 
-async def maybe_update_managed_attributes(
-    session: Session, candidate: PhotometerInfo, source: ReadingSource
-) -> None:
-    photometer = await find_photometer_by_name(session, candidate.name)
+def maybe_update_managed_attributes(
+    session: Session, candidate: PhotometerInfo, photometer: Tess
+) -> bool:
     if changed_managed_attributes(photometer, candidate):
-        update_managed_attributes(session, photometer, candidate, source)
-    else:
-        # self.nReboot += 1
-        pub.sendMessage(RegisterEvent.PHOT_RESET, source=source)
-        log.info(
-            "Detected reboot for photometer %s (MAC = %s)", candidate.name, candidate.mac_address
-        )
+        update_managed_attributes(session, photometer, candidate)
+        return True
+    return False
 
 
 # ===================
@@ -451,7 +463,7 @@ async def photometer_register(
         # This means that we are probably replacing a broken photometer with a new one, keeping the same name.
         # STATS CODE
         # self.nReplace += 1
-        await replacing_photometer(session, old_name_entry, candidate)
+        await replacing_photometer(session, old_name_entry, candidate, source)
         pub.sendMessage(RegisterOp.REPLACE, source=source)
         log.info(
             "Replaced photometer tagged %s (old MAC = %s) with new one with MAC %s",
@@ -468,7 +480,19 @@ async def photometer_register(
             candidate.name == old_mac_entry.name
             and candidate.mac_address == old_name_entry.mac_address
         ):
-            await maybe_update_managed_attributes(session, candidate, source)
+            photometer = await find_photometer_by_name(session, candidate.name)
+            updated = maybe_update_managed_attributes(session, candidate, photometer)
+            if updated:
+                # self.nZPChange += 1
+                pub.sendMessage(RegisterEvent.ZP_CHANGE, source=source)
+            else:
+                # self.nReboot += 1
+                pub.sendMessage(RegisterEvent.PHOT_RESET, source=source)
+                log.info(
+                    "Detected reboot for photometer %s (MAC = %s)",
+                    candidate.name,
+                    candidate.mac_address,
+                )
         else:
             log.info(
                 "Overridden associations (%s -> %s) and (%s -> %s) with new (%s -> %s) association data",
